# `Calculators`

::: molfeat.calc

### `Fingerprints`
::: molfeat.calc.fingerprints

----


### `Descriptors`
::: molfeat.calc.descriptors

----

### `CATS`
::: molfeat.calc.cats

----


### `Pharmacophore`
::: molfeat.calc.pharmacophore

----

### `Scaffold Keys`
::: molfeat.calc.skeys

----

### `Shape`
::: molfeat.calc.shape

----

### `Atoms Featurizer`
::: molfeat.calc.atom

----

### `Bonds Featurizer`
::: molfeat.calc.bond

----
